@@ -44,14 +44,12 @@ Specified at L<WWW::Search>.
 C<WWW::Search::guru> is written and maintained
 by Glenn Wood, <glenwood@dnai.com>.
 
-The best place to obtain C<WWW::Search::guru>
-is from Martin Thurn's WWW::Search releases on CPAN.
-Because guru sometimes changes its format
-in between his releases, sometimes more up-to-date versions
-can be found at
+The best place to obtain C<WWW::Search::theWorksUSA>
+is from Glenn's releases on CPAN. Because www.theWorksUSA.com
+sometimes changes its format in between his releases, 
+sometimes more up-to-date versions can be found at
 F<http://alumni.caltech.edu/~glenwood/SOFTWARE/index.html>.
 
-
 =head1 COPYRIGHT
 
 Copyright (c) 2001 Glenn Wood
@@ -70,7 +68,7 @@ require Exporter;
 @EXPORT = qw();
 @EXPORT_OK = qw(trimTags);
 @ISA = qw(WWW::Search::Scraper Exporter);
-$VERSION = sprintf("%d.%02d", q$Revision: 1.1 $ =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%02d", q$Revision: 1.2 $ =~ /(\d+)\.(\d+)/);
 
 use Carp ();
 use WWW::Search::Scraper(qw(1.34 generic_option addURL trimTags));
